/* Routines for sending stuff to the network.
 * Auspice Services is copyright (c) 2000-2001 In Mean.
 *     E-mail: <inmean@pleaselook.com>
 *
 * SirvNET Services is copyright (c) 1998-2000 Trevor Klingbeil.
 *     E-mail: <priority1@dal.net>
 * Originally based on EsperNet Services(c) by Andy Church.
 * This program is free but copyrighted software; see the file LICENSE for
 * details.
 */

#include "../inc/services.h"

/*************************************************************************/

/* Send a command to the server.  The two forms here are like
 * printf()/vprintf() and friends. */

void send_cmd(const char *source, const char *fmt, ...)
{
    va_list args;

    va_start(args, fmt);
    vsend_cmd(source, fmt, args);
    va_end(args);
}

void vsend_cmd(const char *source, const char *fmt, va_list args)
{
    char buf[2048];	/* better not get this big... */

    vsnprintf(buf, sizeof(buf), fmt, args);
    if (source) {
	sockprintf(servsock, ":%s %s\r\n", source, buf);
        if (debug && !sndebug)
	    log("debug: Sent: :%s %s", source, buf);
    } else {
	sockprintf(servsock, "%s\r\n", buf);
        if (debug && !sndebug)
	    log("debug: Sent: %s", buf);
    }
}

/*************************************************************************/

/* Send out a GLOBOPS.  This is called wallops() because it historically
 * sent a WALLOPS.
 * (Actually, it still does on servers other than ircd.dal...) */

void wallops(const char *source, const char *fmt, ...)
{
    va_list args;
    char buf[BUFSIZE];

    va_start(args, fmt);
    snprintf(buf, sizeof(buf), "GLOBOPS :%s", fmt);
    vsend_cmd(source ? source : server_name, buf, args);
}

void chatops(const char *source, const char *fmt, ...)
{
    va_list args;
    char buf[BUFSIZE];

    va_start(args, fmt);
    snprintf(buf, sizeof(buf), "CHATOPS :%s", fmt);
    vsend_cmd(source ? source : server_name, buf, args);
}

void global_note(const char *source, const char *fmt, ...)
{
    va_list args;
    char buf[BUFSIZE];

    va_start(args, fmt);

    if (SPRIV == 0)
	    snprintf(buf, sizeof(buf), "NOTICE $* :%s", fmt);
    else
	    snprintf(buf, sizeof(buf), "PRIVMSG $* :%s", fmt);

    vsend_cmd(s_GlobalNoticer, buf, args);
}

/*************************************************************************/

/* Send a NOTICE from the given source to the given nick. */

void notice(const char *source, const char *dest, const char *fmt, ...)
{
    va_list args;
    char buf[BUFSIZE];
    NickInfo *ni;

    va_start(args, fmt);

    if ((SPRIV == 1) || ((ni = findnick (dest)) && (ni->flags & NI_PRIVMSG)))
	    snprintf(buf, sizeof(buf), "PRIVMSG %s :%s", dest, fmt);
    else
	    snprintf(buf, sizeof(buf), "NOTICE %s :%s", dest, fmt);

    vsend_cmd(source, buf, args);
    va_end(args);

}

/* Send a NULL-terminated array of text as NOTICEs. */
void notice_list(const char *source, const char *dest, const char **text)
{
    while (*text) {
	/* Have to kludge around an ircII bug here: if a notice includes
	 * no text, it is ignored, so we replace blank lines by lines
	 * with a single space.
	 */
	if (**text)
	    notice(source, dest, *text);
	else
	    notice(source, dest, " ");
	text++;
    }
}

/*************************************************************************/

/* Send a PRIVMSG from the given source to the given nick. */
void privmsg(const char *source, const char *dest, const char *fmt, ...)
{
    va_list args;
    char buf[BUFSIZE];

    va_start(args, fmt);
    snprintf(buf, sizeof(buf), "PRIVMSG %s :%s", dest, fmt);
    vsend_cmd(source, buf, args);
}

/*************************************************************************/
void adchat(const char *source, const char *dest, const char *fmt, ...)
{
    va_list args;
    char buf[BUFSIZE];

    va_start(args, fmt);

    snprintf(buf, sizeof(buf), "ADCHAT %s :%s", dest, fmt);

    vsend_cmd(source, buf, args);
    va_end(args);

}
/**************************************************************************/
